======
Silvio
======


.. image:: https://img.shields.io/pypi/v/silvio.svg
        :target: https://pypi.python.org/pypi/silvio

.. image:: https://readthedocs.org/projects/silvio/badge/?version=latest
        :target: https://silvio.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




silvio is an environment to combine microbiological models to simulate virtual cells.

* Authors: Ulf Liebal, Rafael Schimassek, Lars Blank
* Contact: ulf.liebal@rwth-aachen.de
* Licence: MIT Licence
* Free software: MIT license
* Documentation: https://silvio.readthedocs.io


Features
--------

* Simulate different components of a biological host using event-driven messaging.
* Produce data on procedures performed on the host at the given state.


Credits
-------

Extensive credits can be found in the author notes.
